# Swarm Ecosystem

Welcome to the Swarm Ecosystem, a comprehensive suite of tools and frameworks designed to empower developers to orhestrate swarms of autonomous agents for a variety of applications. Dive into our ecosystem below:

[Full Github Link](https://github.com/kyegomez/swarm-ecosystem)

## Getting Started

| Project                     | Description                                                                                                                                                                                                                                                                                                           | Link                                                                                         |
| --------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------- |
| **swarms Framework**        | A Python-based framework that enables the creation, deployment, and scaling of reliable swarms of autonomous agents aimed at automating complex workflows.                                                                                                                                                            | [swarms Framework](https://github.com/kyegomez/swarms)                                       |
| **swarms Cloud**            | A cloud-based service offering swarms-as-a-Service with guaranteed 100% uptime, cutting-edge performance, and enterprise-grade reliability for seamless scaling and management of swarms.                                                                                                                             | [swarms Cloud](https://github.com/kyegomez/swarms-cloud)                                     |
| **swarms Core**             | Provides backend utilities focusing on concurrency, multi-threading, and advanced execution strategies, developed in Rust for maximum efficiency and performance.                                                                                                                                                     | [swarms Core](https://github.com/kyegomez/swarms-core)                                       |
| **Swarm Foundation Models** | A dedicated repository for the creation, optimization, and training of groundbreaking swarming models. Features innovative models like PSO with transformers, ant colony optimizations, and more, aiming to surpass traditional architectures like Transformers and SSMs. Open for community contributions and ideas. | [Swarm Foundation Models](https://github.com/kyegomez/swarms-pytorch)                        |
| **Swarm Platform**          | The swarms dashboard Platform                                                                                                                                                                                                                                                                                         | [Swarm Platform](https://github.com/kyegomez/swarms-platform)                                |
| **swarms JS**               | swarms Framework in JS. Orchestrate any agents and enable multi-agent collaboration between various agents!                                                                                                                                                                                                           | [Swarm JS](https://github.com/kyegomez/swarms-js)                                            |
| **swarms Memory**           | Easy to use, reliable, and bleeding-edge RAG systems.!                                                                                                                                                                                                                                                                | [Swarm JS](https://github.com/kyegomez/swarms-memory)                                        |
| **swarms Evals**            | Evaluating swarms!                                                                                                                                                                                                                                                                                                    | [Swarm JS](https://github.com/kyegomez/swarms-evals)                                         |
| **swarms Zero**             | RPC Enterprise-Grade Automation Framework                                                                                                                                                                                                                                                                             | [Swarm Zero](<[https://github.com/kyegomez/swarms-evals](https://github.com/kyegomez/Zero)>) |

---

## 🫶 Contributions:

The easiest way to contribute is to pick any issue with the `good first issue` tag 💪. Read the Contributing guidelines [here](/CONTRIBUTING.md). Bug Report? [File here](https://github.com/swarms/gateway/issues) | Feature Request? [File here](https://github.com/swarms/gateway/issues)

swarms is an open-source project, and contributions are VERY welcome. If you want to contribute, you can create new features, fix bugs, or improve the infrastructure. Please refer to the [CONTRIBUTING.md](https://github.com/kyegomez/swarms/blob/master/CONTRIBUTING.md) and our [contributing board](https://github.com/users/kyegomez/projects/1) to participate in Roadmap discussions!

<a href="https://github.com/kyegomez/swarms/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=kyegomez/swarms" />
</a>

<a href="https://github.com/kyegomez/swarms/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=kyegomez/swarms-cloud" />
</a>

<a href="https://github.com/kyegomez/swarms/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=kyegomez/swarms-platform" />
</a>

<a href="https://github.com/kyegomez/swarms/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=kyegomez/swarms-js" />
</a>

---

## Community

Join our growing community around the world, for real-time support, ideas, and discussions on swarms 😊

- View our official [Blog](https://docs.swarms.world)
- Chat live with us on [Discord](https://discord.gg/kS3rwKs3ZC)
- Follow us on [Twitter](https://twitter.com/kyegomez)
- Connect with us on [LinkedIn](https://www.linkedin.com/company/the-swarm-corporation)
- Visit us on [YouTube](https://www.youtube.com/channel/UC9yXyitkbU_WSy7bd_41SqQ)
- [Join the swarms community on Discord!](https://discord.gg/AJazBmhKnr)
- Join our swarms Community Gathering every Thursday at 1pm NYC Time to unlock the potential of autonomous agents in automating your daily tasks [Sign up here](https://lu.ma/5p2jnc2v)

---

## Discovery Call

Book a discovery call to learn how swarms can lower your operating costs by 40% with swarms of autonomous agents in lightspeed. [Click here to book a time that works for you!](https://calendly.com/swarm-corp/30min?month=2023-11)

## Accelerate Backlog

Help us accelerate our backlog by supporting us financially! Note, we're an open source corporation and so all the revenue we generate is through donations at the moment ;)

<a href="https://polar.sh/kyegomez"><img src="https://polar.sh/embed/fund-our-backlog.svg?org=kyegomez" /></a>

---
